@@ -14,7 +14,7 @@ from extended_logger import get_logger
 from time_tools import TimestampSec
 
 from entity_view.viewable_entity import ViewableEntity
-from sql_field import NoDefault
+from entity_field import NoDefault
 
 logger = get_logger(__name__)
 SPACE = " "
